@@ -3,10 +3,10 @@ context("Checking loc_split")
 test_that("loc_split gived intended output",{
 	
     vect_list_check <- function(x){
-        data.frame(is.list = is.list(x),
-            type = c(unique(sapply(x, function(y) class(y)[1]))),
+        list(is.list = is.list(x),
+            type = c(unique(unlist(lapply(x, function(y) class(y)[1])))),
             n = length(x),
-            names.null = is.null(names(x)), stringsAsFactors = FALSE
+            names.null = is.null(names(x))
         )
     }
     
@@ -36,26 +36,13 @@ test_that("loc_split gived intended output",{
     mat <- matrix(1:50, nrow=10)
     x6 <- loc_split(mat, c(3, 6, 10))
     
-    vect_list <- list(structure(list(is.list = TRUE, type = "character", n = 4L, 
-            names.null = TRUE), class = "data.frame", row.names = c(NA, 
-        -1L)), structure(list(is.list = TRUE, type = "character", n = 4L, 
-            names.null = FALSE), class = "data.frame", row.names = c(NA, 
-        -1L)), structure(list(is.list = TRUE, type = "ordered", n = 12L, 
-            names.null = TRUE), class = "data.frame", row.names = c(NA, 
-        -1L)), structure(list(is.list = TRUE, type = "list", n = 4L, 
-            names.null = TRUE), class = "data.frame", row.names = c(NA, 
-        -1L)), structure(list(is.list = TRUE, type = "data.frame", n = 14L, 
-            names.null = TRUE), class = "data.frame", row.names = c(NA, 
-        -1L)), structure(list(is.list = TRUE, type = "matrix", n = 4L, 
-            names.null = TRUE), class = "data.frame", row.names = c(NA, 
-        -1L)))
+    vect_list <- list(list(is.list = TRUE, type = "character", n = 4L, names.null = TRUE), 
+                      list(is.list = TRUE, type = "character", n = 4L, names.null = FALSE), 
+                      list(is.list = TRUE, type = "ordered", n = 12L, names.null = TRUE), 
+                      list(is.list = TRUE, type = "list", n = 4L, names.null = TRUE), 
+                      list(is.list = TRUE, type = "data.frame", n = 14L, names.null = TRUE), 
+                      list(is.list = TRUE, type = "matrix", n = 4L, names.null = TRUE))
     
-    # list(vect_list_check(x1), 
-    # vect_list_check(x2), 
-    # vect_list_check(x3), 
-    # vect_list_check(x4), 
-    # vect_list_check(x5), 
-    # vect_list_check(x6)) 
     
     expect_equal(vect_list_check(x1), vect_list[[1]])
     expect_equal(vect_list_check(x2), vect_list[[2]])
